package org.apache.zookeeper.common;

import org.bouncycastle.jcajce.provider.BouncyCastleFipsProvider;
import org.bouncycastle.jsse.provider.BouncyCastleJsseProvider;

import javax.net.ssl.SSLContext;
import java.security.NoSuchAlgorithmException;
import java.security.Provider;
import java.security.Security;

/**
  * The purpose of this class is to separate the importing of the Bouncy Castle jar
  * files from the classes where they are (conditionally) needed, as those classes
  * may also be used where the Bouncy Castle jar files are not in the classpath.
  * (See MFS-12315)
  */

public class ZKFipsLoader {

  public static void loadZKFipsProviders() {
    java.security.Security.addProvider(new BouncyCastleFipsProvider());
    java.security.Security.addProvider(new BouncyCastleJsseProvider("fips:org.bouncycastle.tls.crypto.impl.jcajce.JcaTlsCryptoProvider"));
  }

  public static boolean isFipsMode() {
    Provider provider = Security.getProvider(BouncyCastleJsseProvider.PROVIDER_NAME);
    return provider != null && provider.getClass() == BouncyCastleJsseProvider.class && ((BouncyCastleJsseProvider)provider).isFipsMode() ;
  }

  public static SSLContext getBCFKSSSLContext(String protocol) throws NoSuchAlgorithmException {
    return SSLContext.getInstance(protocol,Security.getProvider(BouncyCastleJsseProvider.PROVIDER_NAME));
  }
}
